.g-terms-editor-group .alert{margin-top:5px;padding:10px}.g-modal-content .g-terms-info{background-color:#f4f4f4;padding:5px;max-height:20em;overflow-y:auto}.g-terms-container .g-terms-info{background-color:#f4f4f4;padding:5px;margin-bottom:10px}
